@@ -6,7 +6,7 @@
 # URL: <https://github.com/Yzstr/CRTK>
 # For license information, see LICENSE
 
-from crtk.utilities import opcode_occurrence
+from CRTK.utilities import opcode_occurrence
 
 
 class Contract(object):
