@@ -8,7 +8,7 @@
 
 # import sha3
 
-from crtk.mapping import opcode_mapping, push_mapping
+from CRTK.mapping import opcode_mapping, push_mapping
 
 
 def get_opcode_list(bytecode):
